/**********************************************************
*                 FT990.h                                 *
*   							  *
*   This include file provides all the commands and       *
*   return Record format from all commands                *
**********************************************************/

/*   Date	Version		Author		Description
    --------	-------		----------	--------------------------
    06-24-92    1.00		Robert Cartier	Program Creation
    12-16-92    1.10            ''              Reworked some structures for
                                                status update
*/

/* define Commands */

#define SPLIT		0x01	/*  switch split vfo operation on/1 off/0 */
#define RECALL_MEM	0x02    /*  recalls memory number channel 01 - 5ah */
#define VFO_M		0x03    /*  copy display to memory channel */
#define LOCK_DIAL	0x04	/*  lock vfo knob */
#define SELECT_VFO	0x05	/*  select a/b vfo */
#define M_VFO		0x06	/*  copy memory channel t last used vfo */
#define UP		0x07	/*  step current display (0=+100khz) (1=+1mhz)*/
#define DOWN		0x08	/*  step current display (0=-100khz) (1=-1mhz)*/
#define CLARFIER	0x09	/*  see manual for tx/rx clarifier info */
#define SET_FREQ	0x0a	/*  enter new op freq in BCD format */
#define SET_MODE	0x0c	/*  set op mode LSB/USB/CW/AM/FM/RTTY/PKT */
#define HAM_GEN		0x0d	/*  (FT-890) Set HAM/GEN Mode */
#define PACING		0x0e	/*  add delay to character pacing */
#define PTT		0x0f	/*  transmitter on/1 off/0  */
#define UPDATE		0x10	/*  instructs radio to return status */
#define ANT_TUNER	0x81	/*  turn on antenna tuner */
#define TUNER_START	0x82	/*  start antenna tuner */
#define DUAL		0x83	/*  (FT-1000) Activate dual reception */
#define RPT_SHIFT	0x84	/*  select repeater offset sinplex/+/- */
#define A_EQUAL_B	0x85	/*  copy displayed vfo to other vfo */
#define SET_SUB_VFO	0x8a	/*  (FT-1000) Set sub VFO frequency */
#define BANDWIDTH	0x8c	/*  select bandwidth 250/500/2.2k/2.4k */
#define MEMORY_SKIP	0x8d	/*  skip specified mem channel during scan */
#define STEP_FREQ	0x8e	/*  step operating freq up/down */
#define CTCSS		0x90	/*  (FT-890) select a ctcss tone */
#define READ_METER	0xf7	/*  read meter depedent on position */
#define DIM_LEVEL	0xf8	/*  dim level of amber display */
#define RPT_OFFSET	0xf9	/*  repeater offset in BCD */
#define READ_FLAGS	0xfa	/*  read 24 1-bit status flags & 2 bytes pad */

#define ON		0x01
#define TRUE		0x01

#define OFF		0x00
#define FALSE		0x00

#define COMMAND_SIZE	0x05	/* maximum characters sent for command */
#define UPDATE_DATA_SIZE 1492   /* maximum update response */

typedef unsigned char	BYTE;	/* 8 bits  */
typedef unsigned int    WORD;	/* 16 bits */

typedef struct BYTE_MAP{
    unsigned	bit_0 : 1,
		bit_1 : 1,
		bit_2 : 1,
		bit_3 : 1,
		bit_4 : 1,
		bit_5 : 1,
		bit_6 : 1,
		bit_7 : 1;
}BYTE_MAP;

typedef struct BYTE_16{
    BYTE	bpf,
		freq1,
		freq2,
		freq3,
		clarifier,
		offset1,
		offset2,
		mode,
		filter,
		ssb,
		cw,
		rtty,
		pkt,
		last_clarifier,
		skip,
		hz;
}BYTE_16;

typedef struct WORD_MAP{
    unsigned	bit_0 : 1,
		bit_1 : 1,
		bit_2 : 1,
		bit_3 : 1,
		bit_4 : 1,
		bit_5 : 1,
		bit_6 : 1,
		bit_7 : 1,
		bit_8 : 1,
		bit_9 : 1,
		bit_10: 1,
		bit_11: 1,
		bit_12: 1,
		bit_13: 1,
		bit_14: 1,
		bit_15: 1;
}WORD_MAP;

struct send_command{
    BYTE 	opcode,
		data[4];
}cmd;

struct send_fill{
    BYTE	fill[COMMAND_SIZE];

}cmd_fill;

union send_cmd{ 
	struct	send_command	cmd;
	struct	send_fill	cmd_fill;
}send;


struct rcv_flags{
	BYTE_MAP	byte_1;
	BYTE_MAP	byte_2;
	BYTE_MAP	byte_3;
	BYTE		rig1;
	BYTE		rig2;

}r_flags;

struct read_meter{
    BYTE	meter1,
		meter2,
		meter3,
		meter4,
		pad;
}r_meter;

struct receive_data{
    BYTE 	fill[5];
}r_data;

union receive_command{
	struct	rcv_flags	r_flags;
	struct	read_meter	r_meter;
	struct  receive_data	rcv_data;
}rcv_cmd;

struct receive_update_data{
    BYTE_MAP	byte_1,
		byte_2,
		byte_3;
    BYTE	mem_ch;
    BYTE_16	current,
    		vfo_a,
		vfo_b,
		mem1,
		mem2,
		mem3,
		mem4,
		mem5,
		mem6,
		mem7,
		mem8,
		mem9,
		mem10,
		mem11,
		mem12,
		mem13,
		mem14,
		mem15,
		mem16,
		mem17,
		mem18,
		mem19,
		mem20,
		mem21,
		mem22,
		mem23,
		mem24,
		mem25,
		mem26,
		mem27,
		mem28,
		mem29,
		mem30,
		mem31,
		mem32,
		mem33,
		mem34,
		mem35,
		mem36,
		mem37,
		mem38,
		mem39,
		mem40,
		mem41,
		mem42,
		mem43,
		mem44,
		mem45,
		mem46,
		mem47,
		mem48,
		mem49,
		mem50,
		mem51,
		mem52,
		mem53,
		mem54,
		mem55,
		mem56,
		mem57,
		mem58,
		mem59,
		mem60,
		mem61,
		mem62,
		mem63,
		mem64,
		mem65,
		mem66,
		mem67,
		mem68,
		mem69,
		mem70,
		mem71,
		mem72,
		mem73,
		mem74,
		mem75,
		mem76,
		mem77,
		mem78,
		mem79,
		mem80,
		mem81,
		mem82,
		mem83,
		mem84,
		mem85,
		mem86,
		mem87,
		mem88,
		mem89,
		mem90;
}r_update_data;

struct receive_update_fill{
    BYTE	fill[1492];
}r_update_fill;

union rcv_update_data{
	struct	receive_update_data	r_update_data;
	struct	receive_update_fill	r_update_fill;
}r_update;
